package com.aucma.dms.service.impl;

//import com.hw.common.core.exception.ServiceException;
//import com.hw.common.core.utils.DateUtils;
//import com.hw.common.security.utils.SecurityUtils;
//import com.aucma.dms.domain.DmsBaseInspectStandard;
//import com.aucma.dms.mapper.DmsBaseInspectStandardMapper;
//import com.aucma.dms.service.IDmsBaseInspectStandardService;
//import com.hw.system.api.model.LoginUser;

import com.aucma.common.core.domain.model.LoginUser;
import com.aucma.common.exception.ServiceException;
import com.aucma.common.utils.DateUtils;
import com.aucma.common.utils.SecurityUtils;
import com.aucma.dms.domain.DmsBaseInspectStandard;
import com.aucma.dms.mapper.DmsBaseInspectStandardMapper;
import com.aucma.dms.service.IDmsBaseInspectStandardService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 巡检标准信息Service业务层处理
 *
 * @author Open Platform
 * @date 2024-01-17
 */
@Service
public class DmsBaseInspectStandardServiceImpl implements IDmsBaseInspectStandardService
{
    @Autowired
    private DmsBaseInspectStandardMapper dmsBaseInspectStandardMapper;

    /**
     * 查询巡检标准信息
     *
     * @param inspectStandardId 巡检标准信息主键
     * @return 巡检标准信息
     */
    @Override
    public DmsBaseInspectStandard selectDmsBaseInspectStandardByInspectStandardId(Long inspectStandardId)
    {
        return dmsBaseInspectStandardMapper.selectDmsBaseInspectStandardByInspectStandardId(inspectStandardId);
    }

    /**
     * 查询巡检标准信息列表
     *
     * @param dmsBaseInspectStandard 巡检标准信息
     * @return 巡检标准信息
     */
    @Override
    public List<DmsBaseInspectStandard> selectDmsBaseInspectStandardList(DmsBaseInspectStandard dmsBaseInspectStandard)
    {
        return dmsBaseInspectStandardMapper.selectDmsBaseInspectStandardList(dmsBaseInspectStandard);
    }

    /**
     * 新增巡检标准信息
     *
     * @param dmsBaseInspectStandard 巡检标准信息
     * @return 结果
     */
    @Override
    public int insertDmsBaseInspectStandard(DmsBaseInspectStandard dmsBaseInspectStandard)
    {
        DmsBaseInspectStandard InspectStandard = new DmsBaseInspectStandard();
        InspectStandard.setStandardCode(dmsBaseInspectStandard.getStandardCode());
        List<DmsBaseInspectStandard> dmsBaseInspectStandardList = dmsBaseInspectStandardMapper.
                selectDmsBaseInspectStandardList(InspectStandard);
        if (dmsBaseInspectStandardList.size() > 0){throw new ServiceException("巡检标准编号已存在");}
        dmsBaseInspectStandard.setIsFlag("1");
        LoginUser user = SecurityUtils.getLoginUser();
        dmsBaseInspectStandard.setCreateBy(user.getUserId());
        dmsBaseInspectStandard.setCreateTime(DateUtils.getNowDate());
        return dmsBaseInspectStandardMapper.insertDmsBaseInspectStandard(dmsBaseInspectStandard);
    }

    /**
     * 修改巡检标准信息
     *
     * @param dmsBaseInspectStandard 巡检标准信息
     * @return 结果
     */
    @Override
    public int updateDmsBaseInspectStandard(DmsBaseInspectStandard dmsBaseInspectStandard)
    {
        DmsBaseInspectStandard InspectStandard = new DmsBaseInspectStandard();
        InspectStandard.setStandardCode(dmsBaseInspectStandard.getStandardCode());
        List<DmsBaseInspectStandard> dmsBaseInspectStandardList = dmsBaseInspectStandardMapper.
                selectDmsBaseInspectStandardList(InspectStandard);
        if (dmsBaseInspectStandardList.size() > 0 && !dmsBaseInspectStandardList.get(0).getInspectStandardId()
                .equals(dmsBaseInspectStandard.getInspectStandardId())){
            throw new ServiceException("巡检标准编号已存在");
        }
        LoginUser user = SecurityUtils.getLoginUser();
        dmsBaseInspectStandard.setUpdateBy(user.getUserId());
        dmsBaseInspectStandard.setUpdateTime(DateUtils.getNowDate());
        return dmsBaseInspectStandardMapper.updateDmsBaseInspectStandard(dmsBaseInspectStandard);
    }

    /**
     * 批量删除巡检标准信息
     *
     * @param inspectStandardIds 需要删除的巡检标准信息主键
     * @return 结果
     */
    @Override
    public int deleteDmsBaseInspectStandardByInspectStandardIds(Long[] inspectStandardIds)
    {
        return dmsBaseInspectStandardMapper.deleteDmsBaseInspectStandardByInspectStandardIds(inspectStandardIds);
    }

    /**
     * 删除巡检标准信息信息
     *
     * @param inspectStandardId 巡检标准信息主键
     * @return 结果
     */
    @Override
    public int deleteDmsBaseInspectStandardByInspectStandardId(Long inspectStandardId)
    {
        return dmsBaseInspectStandardMapper.deleteDmsBaseInspectStandardByInspectStandardId(inspectStandardId);
    }
}
